version

package
v0.0.0-...-bcdcc2b Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 24, 2026 License: MIT Imports: 10 Imported by: 0

Documentation

Overview

Package version queries Google APIs to discover the latest stable Chrome version and the latest Hola browser-extension version. The values are used to build a believable User-Agent and to mimic the extension to Hola's API.

Index

Constants

This section is empty.

Variables

var ErrNoVerData = errors.New("no version data returned")

ErrNoVerData is returned when the Chrome Web Store update endpoint returns no version data for the requested extension.

Functions

func GetChromeVer

func GetChromeVer(ctx context.Context, dialer core.ContextDialer) (string, error)

GetChromeVer returns the latest stable Chrome version for Windows.

func GetExtVer

func GetExtVer(ctx context.Context, prodVersion *string, id string, dialer core.ContextDialer) (string, error)

GetExtVer returns the latest version of a Chrome extension from the Chrome Web Store update endpoint. If prodVersion is nil, a sensible default is used.

Types

This section is empty.

Jump to