Documentation
¶
Overview ¶
Package version queries Google APIs to discover the latest stable Chrome version and the latest Hola browser-extension version. The values are used to build a believable User-Agent and to mimic the extension to Hola's API.
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ErrNoVerData = errors.New("no version data returned")
ErrNoVerData is returned when the Chrome Web Store update endpoint returns no version data for the requested extension.
Functions ¶
func GetChromeVer ¶
GetChromeVer returns the latest stable Chrome version for Windows.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.